@@ -19,13 +19,13 @@ has 'domain_axis' => (
     }
 );
 has 'markers' => (
-    metaclass => 'Collection::Array',
+    traits => [ 'Array' ],
     is => 'rw',
     isa => 'ArrayRef[Chart::Clicker::Data::Marker]',
     default => sub { [] },
-    provides => {
-        'count' => 'marker_count',
-        'push'  => 'add_marker'
+    handles => {
+        'marker_count' => 'count',
+        'add_marker' => 'push'
     }
 );
 has 'name' => (
